#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: networks_sm_devices_performance_history_info
short_description: Information module for networks _sm _devices _performancehistory
description:
  - Information module for Networks Sm Devices Performancehistory Info.
  - Get all networks _sm _devices _performancehistory.
  - Return historical records of various Systems Manager client metrics for desktop
    devices.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
  - cisco.meraki.module_info_pagination
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  networkId:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - NetworkId path parameter. Network ID.
    type: str
  deviceId:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - DeviceId path parameter. Device ID.
    type: str
  perPage:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - PerPage query parameter. The number of entries per page returned. Acceptable
        range is 3 - 1000. Default is 1000.
    type: int
  startingAfter:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - >
        StartingAfter query parameter. A token used by the server to indicate the
        start of the page. Often this is a timestamp or an ID but it is not limited
        to those. This parameter should not be defined by client applications. The
        link for the first, last, prev, or next page in the HTTP Link header should
        define it.
    type: str
  endingBefore:
    description:
      - Information module for Networks Sm Devices Performancehistory Info.
      - >
        EndingBefore query parameter. A token used by the server to indicate the end
        of the page. Often this is a timestamp or an ID but it is not limited to those.
        This parameter should not be defined by client applications. The link for
        the first, last, prev, or next page in the HTTP Link header should define
        it.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for sm getNetworkSmDevicePerformanceHistory
    description: Complete reference of the getNetworkSmDevicePerformanceHistory API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-network-sm-device-performance-history
notes:
  - SDK Method used are
    sm.Sm.get_network_sm_device_performance_history,
  - Paths used are
    get /networks/{networkId}/sm/devices/{deviceId}/performanceHistory,
"""

EXAMPLES = r"""
- name: Get all networks _sm _devices _performancehistory
  cisco.meraki.networks_sm_devices_performance_history_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    perPage: 0
    startingAfter: string
    endingBefore: string
    networkId: string
    deviceId: string
    total_pages: -1
    direction: next
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "cpuPercentUsed": 0,
        "memFree": 0,
        "memWired": 0,
        "memActive": 0,
        "memInactive": 0,
        "networkSent": 0,
        "networkReceived": 0,
        "swapUsed": 0,
        "diskUsage": {
          "c": {
            "used": 0,
            "space": 0
          }
        },
        "ts": "string"
      }
    ]
"""
